package com.zhaoliangsz.grainsearch.service.impl;

import com.zhaoliangsz.grainsearch.domain.entity.TestTable;
import com.zhaoliangsz.grainsearch.mapper.TestTableMapper;
import com.zhaoliangsz.grainsearch.service.ITestTableService;
import com.baomidou.mybatisplus.extension.service.IService;
import org.springframework.stereotype.Service;
import com.zhaoliangsz.grainsearch.basic.exception.ServiceException;
import com.zhaoliangsz.grainsearch.basic.result.PageResult;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import org.springframework.transaction.annotation.Transactional;
import com.zhaoliangsz.grainsearch.basic.exception.ExceptionDefinition;
/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author chengchangjiang
 * @since 2023-08-21 14:40:08
 */
@Slf4j
@Service
public class TestTableServiceImpl extends ServiceImpl<TestTableMapper, TestTable> implements ITestTableService {
    @Override
    public PageResult<TestTable> queryTestTableList(TestTable queryTestTable) throws ServiceException{
        try{
            Map<String,Object>pageView=new HashMap<>();
            pageView.put("startRecord",(queryTestTable.getCurrentPage()-1)
            *queryTestTable.getPageSize());
            pageView.put("pageSize",queryTestTable.getPageSize());
            pageView.put("currentPage",queryTestTable.getCurrentPage());
            Integer dataCount=baseMapper.getCountByCondition(pageView);
            List<TestTable>dataList=baseMapper.getListByCondition(pageView);
            return new PageResult<>(dataList==null?new ArrayList<>():dataList,dataCount==null?0:dataCount);
        }
        catch(Exception ex){
            log.error("[TestTableServiceImpl.queryTestTableList]异常:{}",ex.toString());
            throw new ServiceException(ExceptionDefinition.QUERY_DATA_EXCEPTION);
        }
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public String addTestTable(TestTable addTestTable) throws ServiceException {
        boolean flag = this.save(addTestTable);
        if(flag){
            return "ok";
        }
        else{
            throw new ServiceException(ExceptionDefinition.ADD_DATA_EXCEPTION);
        }
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public String editTestTable(TestTable editTestTable) throws ServiceException {
        boolean flag = this.updateById(editTestTable);
        if(flag){
            return "ok";
        }
        else{
            throw new ServiceException(ExceptionDefinition.EDIT_DATA_EXCEPTION);
        }
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public String deleteTestTable(TestTable deleteTestTable) throws ServiceException {
        boolean flag = this.removeById(deleteTestTable);
        if(flag){
            return "ok";
        }
        else{
            throw new ServiceException(ExceptionDefinition.DELETE_DATA_EXCEPTION);
        }
    }
}
